PRO vs_snr, state, flux, Lambda, SNR
;; flux is in mJy, lambda in micron
;;
COMMON vs_block
IF NOT vs_debug THEN on_error, 2
;;
;;
;; 10 micron SNR calculator for VLTI/MIDI
  
  WarmTrans = 0.4               ;Transmission of warm optics
  ColdTrans = 0.6               ;Transmission of cold optics
  VLTITrans = 0.4               ;Transmission of VLTI
  VisLoss = 0.6                 ;Visbility transmission (t/t errors etc.)
  QuantEff = 0.4                ;Detector quantum efficieny
  DeltaLambda = 4d-6            ;Spectral Width
  Lambda = 10d-6                ;Wavelength

;;
  WarmTemp = 290                ;Temperature of warm optics
  WarmEmm = 0.5                 ;Emmisivity of warm optics
  SNRStan = 4.4                 ;SNR for a standard star of 390mJy
  mJy4p4 = 390
  mJy10 = 890                   ;mJanskys required for SNR 10
  BaseInt1 = 0.005              ;Basic integration time
  BaseInt2 = 0.025              ;Basic integration time
  BackElectrons = 1.25d9*6./5.  ;Background Electrons per 25ms Itime
  ReadNoise = 1000.             ;Electrons per pixel per readout
;;
  PhotonEnergy = 6.64d-34*3d8/Lambda
  QuantEff = 1.0                ;Assumed detector quantum efficiency
  cLight = 3d8                  ;Speed of light
;;
;; Now do the numerical calculations
  NumPhotons = Flux*1d-29/PhotonEnergy*!pi*4.0^2*state.DIT
  ;; Finite filter width yields more source photons
  IF state.FilterW NE 0 THEN BEGIN 
      LamWidth = Lambda*state.FilterW
      FreqWidth = cLight/Lambda^2*LamWidth
      NumPhotons = NumPhotons*FreqWidth
  ENDIF
  
  NumElectrons = NumPhotons*WarmTrans*ColdTrans*QuantEff*VLTITrans*VisLoss*state.NDIT 
  ;;
  Noise = sqrt((NumElectrons+BackElectrons)*state.NDIT)+ReadNoise*state.NDIT 
                                ;background assumed independent of filter width
  SNR = NumElectrons/Noise
  IF vs_debug THEN print, 'Calculated mean SNR:', mean(snr)
END



